Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1890)

Unified Diff: chrome/browser/renderer_host/render_view_host_delegate.h

Issue 113925: Linux: work around the fact that the download dialog has not been ported.... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 11 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/renderer_host/render_view_host.cc ('k') | chrome/browser/renderer_host/render_widget_host.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/renderer_host/render_view_host_delegate.h
===================================================================
--- chrome/browser/renderer_host/render_view_host_delegate.h (revision 17020)
+++ chrome/browser/renderer_host/render_view_host_delegate.h (working copy)
@@ -421,10 +421,10 @@
int32 page_id,
const webkit_glue::WebApplicationInfo& app_info) { }
// Notification the user has pressed enter or space while focus was on the
// page. This is used to avoid uninitiated user downloads (aka carpet
// bombing), see DownloadRequestManager for details.
- virtual void OnEnterOrSpace() { }
+ virtual void OnUserGesture() { }
// If this view is used to host an external tab container.
virtual bool IsExternalTabContainer() const { return false; }
« no previous file with comments | « chrome/browser/renderer_host/render_view_host.cc ('k') | chrome/browser/renderer_host/render_widget_host.h » ('j') | no next file with comments »
@@ -421,10 +421,10 @@
int32 page_id,
const webkit_glue::WebApplicationInfo& app_info) { }
- // Notification the user has pressed enter or space while focus was on the
+ // Notification the user has made a gesture while focus was on the
// page. This is used to avoid uninitiated user downloads (aka carpet
// bombing), see DownloadRequestManager for details.

Powered by Google App Engine
This is Rietveld 408576698